The "math" extension functions are written by Liam Healy and made available
through the SQLite website (https://www.sqlite.org/src/ext/contrib).
This package contains a slightly modified version of the original code.
See the section "Available functions in the math extension" for details.
The "regexp" extension provides a regular-expression matcher for POSIX
extended regular expressions,
as available through the SQLite source code repository
(https://sqlite.org/src/file?filename=ext/misc/regexp.c).
SQLite will then implement the A regexp B operator,
where A is the string to be matched and B is the regular expression.
The "series" extension loads the table-valued function generate_series(),
as available through the SQLite source code repository
(https://sqlite.org/src/file?filename=ext/misc/series.c).
The "csv" extension loads the function csv() that can be used to create
virtual tables,
as available through the SQLite source code repository
(https://sqlite.org/src/file?filename=ext/misc/csv.c).
The "http" extension registers an HTTP/HTTPS virtual file system (VFS)
that allows opening remote databases via URI filenames, e.g.,
"file:https://host/path/db.sqlite?vfs=http&immutable=1". This implementation
is experimental and not an official SQLite extension; it fetches pages on
demand using HTTP Range requests and serves reads from an in-memory page
cache, with an optional full-download fallback depending on server support
and configuration.
It is primarily intended for read-only access to small, immutable databases;
see sqliteHttpConfig() and
sqliteRemote() for configuration options and
usage examples.
Building this extension may require libcurl and is optional in RSQLite.
The "uuid" extension loads the functions uuid(), uuid_str(X) and
uuid_blob(X) that can be used to create universally unique identifiers,
as available through the SQLite source code repository
(https://sqlite.org/src/file?filename=ext/misc/uuid.c).